==> worker_2.4.0.orig.tar.gz: worker-2.4.0/src/shortkeyfromlistop.h <==
/* shortkeyfromlistop.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: shortkeyfromlistop.h,v 1.1 2001/12/11 23:12:55 ralf Exp $ */

#ifndef SHORTKEYFROMLIST_H
#define SHORTKEYFROMLIST_H

#include "wdefines.h"
#include "functionproto.h"

class Worker;

class ShortkeyFromListOp:public FunctionProto
{
public:
  ShortkeyFromListOp(Worker*);
  virtual ~ShortkeyFromListOp();
  virtual ShortkeyFromListOp *duplicate();
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  // Infos to save

  // temp variables
  Lister *startlister;
};

#endif

==> worker_2.8.4.orig.tar.gz: worker-2.8.4/src/shortkeyfromlistop.h <==
/* shortkeyfromlistop.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001 Ralf Hoffmann.
 * You can contact me at: ralf.hoffmann@epost.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: shortkeyfromlistop.h,v 1.2 2003/05/04 01:16:38 ralf Exp $ */

#ifndef SHORTKEYFROMLIST_H
#define SHORTKEYFROMLIST_H

#include "wdefines.h"
#include "functionproto.h"

class ShortkeyFromListOp:public FunctionProto
{
public:
  ShortkeyFromListOp();
  virtual ~ShortkeyFromListOp();
  virtual ShortkeyFromListOp *duplicate() const;
  virtual bool isName(const char *);
  virtual const char *getName();
  virtual int run(ActionMessage*);
  virtual const char *getDescription();
protected:
  static const char *name;
  // Infos to save

  // temp variables
  Lister *startlister;
};

#endif
